<?php
/**
 * Core file.
 *
 * This is the template that includes all the other files for core featured of Theme Palace
 *
 * @package Theme Palace
 * @subpackage BlogSlog Pro
 * @since BlogSlog Pro 1.0.0
 */

/**
 * Load theme updater functions.
 * Action is used so that child themes can easily disable.
 */
function blogslog_pro_pro_theme_updater() {
    if( is_admin() ) {
        require get_template_directory() . '/inc/updater/theme-updater.php';
    }
}
add_action( 'after_setup_theme', 'blogslog_pro_pro_theme_updater' );

/**
 * Include options function.
 */
require get_template_directory() . '/inc/options.php';


// Load customizer defaults values
require get_template_directory() . '/inc/customizer/defaults.php';


/**
 * Merge values from default options array and values from customizer
 *
 * @return array Values returned from customizer
 * @since BlogSlog Pro 1.0.0
 */
function blogslog_pro_get_theme_options() {
  $blogslog_pro_default_options = blogslog_pro_get_default_theme_options();

  return array_merge( $blogslog_pro_default_options , get_theme_mod( 'blogslog_pro_theme_options', $blogslog_pro_default_options ) ) ;
}

/**
 * Display custom color CSS.
 */
function blogslog_pro_colors_css_wrap() {
    $options= blogslog_pro_get_theme_options();
    if ( 'custom' !== $options['colorscheme'] ) {
        return;
    }

    require get_template_directory() . '/inc/color-pattern.php';
    $color = $options['colorscheme_hue'];
    ?>
    <style type="text/css" id="custom-theme-colors" <?php if ( is_customize_preview() ) { echo 'data-color="' . $color . '"'; } ?>>
        <?php echo blogslog_pro_custom_colors_css(); ?>
    </style>
<?php }
add_action( 'wp_head', 'blogslog_pro_colors_css_wrap' );

/**
 * Load admin custom styles
 * 
 */
function blogslog_pro_load_admin_style() {
    wp_register_style( 'blogslog_pro_admin_css', get_template_directory_uri() . '/assets/css/admin-style.css', false, '1.0.0' );
    wp_enqueue_style( 'blogslog_pro_admin_css' );
}
add_action( 'admin_enqueue_scripts', 'blogslog_pro_load_admin_style' );



/**
 * Add breadcrumb functions.
 */
require get_template_directory() . '/inc/breadcrumb-class.php';

/**
 * Add helper functions.
 */
require get_template_directory() . '/inc/helpers.php';

/**
 * Add structural hooks.
 */
require get_template_directory() . '/inc/structure.php';

/**
 * Add metabox
 */
require get_template_directory() . '/inc/metabox.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/sections/sections.php';

/*
 * Add Instagram widget
 */
require get_template_directory() . '/inc/instagram-widget.php';

/**
* TGM plugin additions.
*/
require get_template_directory() . '/inc/tgm-plugin/tgm-hook.php';

if ( class_exists( 'CatchThemesDemoImportPlugin' ) ) {
    /**
    * OCDI plugin demo importer compatibility.
    */
    require get_template_directory() . '/inc/demo-import.php';
}

/**
* Download webfonts locally.
*/
require get_template_directory() . '/inc/wptt-webfont-loader.php';

if ( ! function_exists( 'blogslog_pro_posts_ajax_handler' ) ) :
 

    function blogslog_pro_posts_ajax_handler(){
        $options = blogslog_pro_get_theme_options();
        $readmore = ! empty( $options['list_articles_readmore'] ) ? $options['list_articles_readmore'] : esc_html__( 'Continue Reading', 'blogslog-pro' );
        $page = isset( $_POST['LBpageNumber'] ) ? absint( wp_unslash( $_POST['LBpageNumber'] ) ) : 1;
        header("Content-Type: text/html");

  
        $latest_posts_args = array(
            'post_type'         => 'post',
            'posts_per_page'    => 5,
            'cat'               => ! empty( $options['list_articles_content_category'] ) ? $options['list_articles_content_category'] : '',
            'ignore_sticky_posts'   => true,
            'post_status'       => array( 'publish' ),
            'paged'             => $page,
            );                    
    
        $latest_posts = new WP_Query( $latest_posts_args );
        $i = 1;
        if ( $latest_posts -> have_posts() ) : while ( $latest_posts -> have_posts() ) : $latest_posts -> the_post(); 
                $content['id']        = get_the_id();
                $content['title']     = get_the_title();
                $content['url']       = get_the_permalink();
                $content['excerpt']   = blogslog_pro_trim_content( 25 );
                $content['author']    = blogslog_pro_author();
                $content['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';
            ?>
            <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-featured-image <?php echo ( $i%2 ) == 0 ? 'even' : '' ?>">
                <?php if ( ! empty( $content['image'] ) ) : ?>
                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                    </div>
                <?php endif; ?>

                <div class="entry-container">
                    <span class="cat-links">
                        <?php the_category( '', '', $content['id'] ); ?>
                    </span>

                    <header class="entry-header">
                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                    </header>

                    <div class="entry-content">
                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                    </div>

                    <div class="entry-meta">
                        <?php 
                            blogslog_pro_posted_on( $content['id'] ); 
                            echo wp_kses_post( $content['author'] );
                        ?>  
                    </div>

                    <div class="read-more">
                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $readmore ); ?></a>
                    </div>
                </div>
            </article>

        <?php $i++; endwhile; endif;
        wp_reset_postdata();
        ?>
        <?php die();
    }
endif;
add_action("wp_ajax_blogslog_pro_posts_ajax_handler", "blogslog_pro_posts_ajax_handler");
add_action("wp_ajax_nopriv_blogslog_pro_posts_ajax_handler", "blogslog_pro_posts_ajax_handler");